﻿/*****************************************************************************************************************************
 * 
 * Reputation System
 * Version 3.0
 * Designed for ForkUO 0.2
 * 
 * Authored by Dougan Ironfist
 * Last Updated on 1/30/2013
 * 
 * The purpose of these scripts is to allow shard administrators to create reputation groups that allow players to complete
 * quests, kill specific creatures and purchase items from reputation vendors based on their current reputation level.
 * This system is very similiar to how reputation systems work in other games.
 * 
 ****************************************************************************************************************************/

using System;
using System.Globalization;
using Server;
using Server.Mobiles;

/// THIS IS A CORE SCRIPT AND SHOULD NOT BE ALTERED ///

namespace Custom.ReputationSystem
{
    public class ReputationItem
    {
        private Item m_Item;
        private Int32 m_Price;
        private ReputationLevel m_RequiredReputation;

        public Item Item { get { return m_Item; } }
        public Int32 Price { get { return m_Price; } }

        public String FormattedPrice
        {
            get
            {
                if (Core.ML)
                    return m_Price.ToString("N0", CultureInfo.GetCultureInfo("en-US"));

                return m_Price.ToString();
            }
        }

        public ReputationLevel RequiredReputation { get { return m_RequiredReputation; } }

        public Boolean IsForSale { get { return Price >= 0; } }

        public ReputationItem(Item item, Int32 price, ReputationLevel requiredReputation)
        {
            m_Item = item;
            m_Price = price;
            m_RequiredReputation = requiredReputation;
        }
    }
}
